@@ -65,13 +65,13 @@ def git_archive(repo, cp, output_dir, treeish, comp_type, comp_level, with_submo
     except (GitRepositoryError, CommandExecFailed):
         gbp.log.err("Error generating submodules' archives")
         return False
-    except OSError as err:
-        gbp.log.err("Error creating %s: %s" % (output, err[0]))
+    except OSError as e:
+        gbp.log.err("Error creating %s: %s" % (output, str(e)))
         return False
     except GbpError:
         raise
     except Exception as e:
-        gbp.log.err("Error creating %s: %s" % (output, e))
+        gbp.log.err("Error creating %s: %s" % (output, str(e)))
         return False
     return True
 
@@ -165,8 +165,8 @@ def move_old_export(target):
     """move a build tree away if it exists"""
     try:
         os.mkdir(target)
-    except OSError as (e, msg):
-        if e == errno.EEXIST:
+    except OSError as e:
+        if e.errno == errno.EEXIST:
             os.rename(target, "%s.obsolete.%s" % (target, time.time()))
 
 
@@ -221,8 +221,8 @@ def prepare_output_dir(dir):
 
     try:
         os.mkdir(output_dir)
-    except OSError as (e, msg):
-        if e != errno.EEXIST:
+    except OSError as e:
+        if e.errno != errno.EEXIST:
             raise GbpError("Cannot create output dir %s" % output_dir)
     return output_dir
 
