@@ -304,6 +304,10 @@ def main(argv):
             if options.verbose:
                 print_dsc(src)
 
+            if src.additional_tarballs:
+                raise GbpError("Cannot import package with additional tarballs but found '%s'" %
+                               ", ".join([os.path.basename(t) for t in src.additional_tarballs]))
+
             try:
                 repo = DebianGitRepository('.')
                 is_empty = repo.is_empty()
@@ -312,13 +316,16 @@ def main(argv):
                 if not clean and not is_empty:
                     gbp.log.err("Repository has uncommitted changes, commit these first: ")
                     raise GbpError(out)
-
             except GitRepositoryError:
                 # no repo found, create one
                 needs_repo = True
                 is_empty = True
 
             if needs_repo:
+                if os.path.exists(src.pkg):
+                    raise GbpError("Directory '%s' already exists. If you want to import into it, "
+                                   "please change into this directory otherwise move it away first."
+                                   % src.pkg)
                 gbp.log.info("No git repository found, creating one.")
                 repo = DebianGitRepository.create(src.pkg)
                 os.chdir(repo.path)
